@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and 
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -39,16 +35,18 @@ import math
 import uuid
 import numpy
 import psutil
+
 from tvb.adapters.datatypes.db.spectral import FourierSpectrumIndex
 from tvb.adapters.datatypes.db.time_series import TimeSeriesIndex
 from tvb.adapters.datatypes.h5.spectral_h5 import FourierSpectrumH5
-from tvb.analyzers.fft import compute_fast_fourier_transform, SUPPORTED_WINDOWING_FUNCTIONS
-from tvb.basic.neotraits.api import Attr, Float
+from tvb.analyzers.fft import compute_fast_fourier_transform
+from tvb.basic.neotraits.api import Attr, EnumAttr, Float
 from tvb.core.adapters.abcadapter import ABCAdapterForm, ABCAdapter
 from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.neocom import h5
 from tvb.core.neotraits.forms import TraitDataTypeSelectField, SelectField, FloatField, BoolField
 from tvb.core.neotraits.view_model import ViewModel, DataTypeGidAttr
+from tvb.datatypes.spectral import WindowingFunctionsEnum
 from tvb.datatypes.time_series import TimeSeries
 
 
@@ -75,10 +73,9 @@ class FFTAdapterModel(ViewModel):
             frequency resolution of the resulting power spectra -- longer
             windows produce finer frequency resolution.""")
 
-    window_function = Attr(
-        field_type=str,
+    window_function = EnumAttr(
+        default=WindowingFunctionsEnum.HAMMING,
         label="Windowing function",
-        choices=tuple(SUPPORTED_WINDOWING_FUNCTIONS),
         required=False,
         doc="""Windowing functions can be applied before the FFT is performed.
              Default is None, possibilities are: 'hamming'; 'bartlett';
@@ -190,7 +187,7 @@ class FourierAdapter(ABCAdapter):
 
         # --------------------- Prepare result entities ----------------------
         fft_index = FourierSpectrumIndex()
-        dest_path = h5.path_for(self.storage_path, FourierSpectrumH5, fft_index.gid)
+        dest_path = self.path_for(FourierSpectrumH5, fft_index.gid)
         spectra_file = FourierSpectrumH5(dest_path)
 
         # ------------- NOTE: Assumes 4D, Simulator timeSeries. --------------
@@ -224,7 +221,7 @@ class FourierAdapter(ABCAdapter):
         self.fill_index_from_h5(fft_index, spectra_file)
 
         spectra_file.store(partial_result, scalars_only=True)
-        spectra_file.windowing_function.store(str(view_model.window_function))
+        spectra_file.windowing_function.store(view_model.window_function)
         spectra_file.close()
 
         self.log.debug("partial segment_length is %s" % (str(partial_result.segment_length)))
