@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and 
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 """
@@ -33,15 +29,14 @@
 import importlib
 import json
 import os
+import numpy
 from abc import ABCMeta
 from threading import Lock
 from uuid import UUID
-
 from six import add_metaclass
 from tvb.core.adapters.abcadapter import AdapterLaunchModeEnum, ABCAdapter
 from tvb.core.adapters.exceptions import LaunchException
 from tvb.core.neocom import h5
-from tvb.core.neotraits.view_model import ViewModel
 
 LOCK_CREATE_FIGURE = Lock()
 
@@ -123,20 +118,12 @@ class ABCDisplayer(ABCAdapter, metaclass=ABCMeta):
     def get_output(self):
         return []
 
-    def generate_preview(self, view_model, figure_size=None):
-        # type: (ViewModel, (int,int)) -> dict
-        """
-        Should be implemented by all visualizers that can be used by portlets.
-        """
-        raise LaunchException("%s used as Portlet but doesn't implement 'generate_preview'" % self.__class__)
-
     def _prelaunch(self, operation, view_model, available_disk_space=0):
         """
         Shortcut in case of visualization calls.
         """
         self.current_project_id = operation.project.id
         self.user_id = operation.fk_launched_by
-        self.storage_path = self.file_handler.get_project_folder(operation.project, str(operation.id))
         return self.launch(view_model=view_model), 0
 
     def get_required_disk_size(self, view_model):
@@ -195,6 +182,20 @@ class ABCDisplayer(ABCAdapter, metaclass=ABCMeta):
         format_str = "%0." + str(precision) + "g"
         return "[" + ",".join(format_str % s for s in xs) + "]"
 
+    @staticmethod
+    def handle_infinite_values(data):
+        """
+        Replace positive infinite values with the biggest float number available in numpy, and negative infinite
+        values with the smallest float number available in numpy.
+        """
+        float_max = numpy.finfo(numpy.float64).max
+        data[data == numpy.PINF] = float_max
+
+        float_min = numpy.finfo(numpy.float64).min
+        data[data == numpy.NINF] = float_min
+
+        return data
+
     @staticmethod
     def prepare_shell_surface_params(shell_surface, surface_url_generator):
         """
@@ -202,8 +203,8 @@ class ABCDisplayer(ABCAdapter, metaclass=ABCMeta):
         """
         if shell_surface:
             shell_h5 = h5.h5_file_for_index(shell_surface)
-            shell_vertices, shell_normals, _, shell_triangles, _ = surface_url_generator.get_urls_for_rendering(shell_h5)
-            shellObject = json.dumps([shell_vertices, shell_normals, shell_triangles])
+            vertices, normals, lines, triangles, _ = surface_url_generator.get_urls_for_rendering(shell_h5)
+            shell_object = json.dumps([vertices, normals, triangles, lines])
             shell_h5.close()
-            return shellObject
+            return shell_object
         return None
