@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and 
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -34,9 +30,8 @@ Higher level entity loading.
 """
 import importlib
 import uuid
+
 from tvb.basic.logger.builder import get_logger
-from tvb.core.entities.file.exceptions import FileVersioningException
-from tvb.core.entities.file.files_update_manager import FilesUpdateManager
 from tvb.core.entities.storage import dao
 
 LOGGER = get_logger(__name__)
@@ -62,17 +57,6 @@ def load_entity_by_gid(data_gid):
     if isinstance(data_gid, uuid.UUID):
         data_gid = data_gid.hex
     datatype = dao.get_datatype_by_gid(data_gid)
-    # TODO
-    # from tvb.core.traits.types_mapped import MappedType
-
-    # if isinstance(datatype, MappedType):
-    #     datatype_path = datatype.get_storage_file_path()
-    #     files_update_manager = FilesUpdateManager()
-    #     if not files_update_manager.is_file_up_to_date(datatype_path):
-    #         datatype.invalid = True
-    #         dao.store_entity(datatype)
-    #         raise FileVersioningException("Encountered DataType with an incompatible storage or data version. "
-    #                                       "The DataType was marked as invalid.")
     return datatype
 
 
