@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and 
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -35,16 +31,16 @@ DAO operations related to generic DataTypes are defined here.
 .. moduleauthor:: Bogdan Neacsa <bogdan.neacsa@codemart.ro>
 """
 import importlib
-from sqlalchemy import func, or_, not_, and_
+
+from sqlalchemy import func, or_, and_
 from sqlalchemy.exc import SQLAlchemyError
-from sqlalchemy.sql import text
 from sqlalchemy.orm import aliased
+from sqlalchemy.orm.exc import NoResultFound
+from sqlalchemy.sql import text
 from sqlalchemy.sql.expression import desc, cast
 from sqlalchemy.types import Text
-from sqlalchemy.orm.exc import NoResultFound
 from tvb.core.entities.model.model_datatype import *
 from tvb.core.entities.model.model_operation import Operation, AlgorithmCategory, Algorithm, OperationGroup
-from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.storage.root_dao import RootDAO, DEFAULT_PAGE_SIZE
 from tvb.core.neotraits.db import Base
 
@@ -54,14 +50,27 @@ class DatatypeDAO(RootDAO):
     DATATYPE and DATA_TYPES_GROUPS RELATED METHODS
     """
 
+    def get_datatypegroup_for_project(self, project_id):
+        """
+        Returns all DataTypeGroup entities from a project.
+        """
+        query = self.session.query(DataTypeGroup
+                                   ).join((OperationGroup, OperationGroup.id == DataTypeGroup.fk_operation_group)
+                                          ).filter(OperationGroup.fk_launched_in == project_id).order_by(DataTypeGroup.id)
+        return query.all()
 
     def get_datatypegroup_by_op_group_id(self, operation_group_id):
         """
         Returns the DataTypeGroup corresponding to a certain OperationGroup.
         """
-        result = self.session.query(DataTypeGroup).filter_by(fk_operation_group=operation_group_id).one()
-        return result
-
+        try:
+            result = self.session.query(DataTypeGroup).filter_by(fk_operation_group=operation_group_id).one()
+            return result
+        except NoResultFound:
+            self.logger.debug("No operation group was found for operation group id = {}".format(operation_group_id))
+        except SQLAlchemyError as excep:
+            self.logger.exception(excep)
+        return None
 
     def get_datatype_group_by_gid(self, datatype_group_gid):
         """
@@ -551,6 +560,25 @@ class DatatypeDAO(RootDAO):
             hdd_size = 0
         return hdd_size
 
+    def get_datatype_measure_group_from_ts_from_pse(self, ts_gid, datatype_measure_class):
+        """
+        Having a Time Series that was part of a pse, this method should return the datatype group of a datatype measure
+        that was part of the same pse
+        """
+        try:
+            datatype_measures = self.session.query(datatype_measure_class).filter_by(fk_source_gid=ts_gid).all()
+            datatype_group = None
+            for dt_measure in datatype_measures:
+                if dt_measure.fk_datatype_group is not None:
+                    datatype_group = self.get_datatypegroup_by_op_group_id(
+                        dt_measure.parent_operation.fk_operation_group)
+                    break
+
+        except SQLAlchemyError as ex:
+            self.logger.exception(ex)
+            datatype_group = None
+        return datatype_group
+
 
     ##########################################################################
     ############ Below are specifics for MeasurePoint selections #############
