@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -36,17 +32,15 @@ After running this script, you should have a message in the console telling wher
 .. moduleauthor:: Lia Domide <lia.domide@codemart.ro>
 
 """
-from tvb.core.services.project_service import ProjectService
-from tvb.core.entities.storage import dao
 from tvb.adapters.exporters.export_manager import ExportManager
 
 
-def run_export(project_id, loose_irrelevant=False):
+def run_export(project_id):
     s = ProjectService()
     mng = ExportManager()
 
     project = s.find_project(project_id)
-    export_file = mng.export_project(project, loose_irrelevant)
+    export_file = mng.export_project(project)
     print("Check the exported file: %s" % export_file)
 
 
