@@ -2,11 +2,11 @@
 #
 #
 # TheVirtualBrain-Framework Package. This package holds all Data Management, and 
-# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,12 +19,8 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
@@ -99,8 +95,7 @@ class BaseController(object):
             IntrospectionRegistry.SIIBRA_CREATOR_MODULE,
             IntrospectionRegistry.SIIBRA_CREATOR_CLASS
         )
-        # TODO temporary disable SIIBRA in tvb-web-gui TVB-3044
-        if False and siibra_algo and not siibra_algo.removed:
+        if siibra_algo and not siibra_algo.removed:
             siibra_link = self.get_url_adapter(siibra_algo.fk_category, siibra_algo.id)
             self.connectivity_submenu.append(dict(title='Siibra Connectivity', link=siibra_link,
                                                   subsection=WebStructure.SUB_SECTION_SIIBRA,
