@@ -1,10 +1,10 @@
 /**
  * TheVirtualBrain-Framework Package. This package holds all Data Management, and
- * Web-UI helpful to run brain-simulations. To use it, you also need do download
+ * Web-UI helpful to run brain-simulations. To use it, you also need to download
  * TheVirtualBrain-Scientific Package (for simulators). See content of the
  * documentation-folder for more details. See also http://www.thevirtualbrain.org
  *
- * (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
+ * (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
  *
  * This program is free software: you can redistribute it and/or modify it under the
  * terms of the GNU General Public License as published by the Free Software Foundation,
@@ -388,6 +388,12 @@ function removeProject(projectId, formId) {
     form.submit();
 }
 
+function leaveProject(projectId, formId) {
+    const form = document.getElementById(formId);
+    form.action = deploy_context + "/project/editone/" + projectId + "/?leave=Leave";
+    form.submit();
+}
+
 // ---------------END PROJECT ------------------------
 
 
