@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 #
 #
-# TheVirtualBrain-Scientific Package. This package holds all simulators, and
-# analysers necessary to run brain-simulations. You can use it stand alone or
-# in conjunction with TheVirtualBrain-Framework Package. See content of the
+# TheVirtualBrain-Framework Package. This package holds all Data Management, and
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
+# TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,32 +19,29 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
 import os
 from io import BytesIO
 from uuid import UUID
-
 import flask
 import pytest
 import tvb_data
-from tvb.adapters.analyzers.fourier_adapter import FFTAdapterModel, SUPPORTED_WINDOWING_FUNCTIONS
+
+from tvb.adapters.analyzers.fourier_adapter import FFTAdapterModel
 from tvb.basic.exceptions import TVBException
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.neocom import h5
 from tvb.core.services.operation_service import OperationService
+from tvb.datatypes.spectral import WindowingFunctionsEnum
 from tvb.interfaces.rest.commons.exceptions import InvalidIdentifierException, ServiceException
 from tvb.interfaces.rest.commons.strings import Strings, RequestFileKey
 from tvb.interfaces.rest.server.resources.operation.operation_resource import GetOperationStatusResource, \
     GetOperationResultsResource, LaunchOperationResource
 from tvb.interfaces.rest.server.resources.project.project_resource import GetOperationsInProjectResource
+from tvb.storage.storage_interface import StorageInterface
 from tvb.tests.framework.core.factory import TestFactory, OperationPossibleStatus
 from tvb.tests.framework.interfaces.rest.base_resource_test import RestResourceTest
 from werkzeug.datastructures import FileStorage
@@ -59,7 +56,7 @@ class TestOperationResource(RestResourceTest):
         self.status_resource = GetOperationStatusResource()
         self.results_resource = GetOperationResultsResource()
         self.launch_resource = LaunchOperationResource()
-        self.files_helper = FilesHelper()
+        self.storage_interface = StorageInterface()
 
     def test_server_get_operation_status_inexistent_gid(self, mocker):
         self._mock_user(mocker)
@@ -71,7 +68,7 @@ class TestOperationResource(RestResourceTest):
         zip_path = os.path.join(os.path.dirname(tvb_data.__file__), 'connectivity', 'connectivity_96.zip')
         TestFactory.import_zip_connectivity(self.test_user, self.test_project, zip_path)
 
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         request_mock.args = {Strings.PAGE_NUMBER: '1'}
 
         operations_and_pages = self.operations_resource.get(project_gid=self.test_project.gid)
@@ -90,7 +87,7 @@ class TestOperationResource(RestResourceTest):
         zip_path = os.path.join(os.path.dirname(tvb_data.__file__), 'connectivity', 'connectivity_96.zip')
         TestFactory.import_zip_connectivity(self.test_user, self.test_project, zip_path)
 
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         request_mock.args = {Strings.PAGE_NUMBER: '1'}
 
         operations_and_pages = self.operations_resource.get(project_gid=self.test_project.gid)
@@ -105,7 +102,7 @@ class TestOperationResource(RestResourceTest):
         with pytest.raises(TVBException):
             TestFactory.import_zip_connectivity(self.test_user, self.test_project, zip_path)
 
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         request_mock.args = {Strings.PAGE_NUMBER: '1'}
 
         operations_and_pages = self.operations_resource.get(project_gid=self.test_project.gid)
@@ -117,7 +114,7 @@ class TestOperationResource(RestResourceTest):
     def test_server_launch_operation_no_file(self, mocker):
         self._mock_user(mocker)
         # Mock flask.request.files to return a dictionary
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         request_mock.files = {}
 
         with pytest.raises(InvalidIdentifierException): self.launch_resource.post(project_gid='', algorithm_module='',
@@ -127,7 +124,7 @@ class TestOperationResource(RestResourceTest):
         self._mock_user(mocker)
         dummy_file = FileStorage(BytesIO(b"test"), 'test.txt')
         # Mock flask.request.files to return a dictionary
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         request_mock.files = {RequestFileKey.LAUNCH_ANALYZERS_MODEL_FILE.value: dummy_file}
 
         with pytest.raises(InvalidIdentifierException): self.launch_resource.post(project_gid='', algorithm_module='',
@@ -138,7 +135,7 @@ class TestOperationResource(RestResourceTest):
         project_gid = "inexistent-gid"
         dummy_file = FileStorage(BytesIO(b"test"), 'test.h5')
         # Mock flask.request.files to return a dictionary
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         request_mock.files = {RequestFileKey.LAUNCH_ANALYZERS_MODEL_FILE.value: dummy_file}
 
         with pytest.raises(InvalidIdentifierException): self.launch_resource.post(project_gid=project_gid,
@@ -151,7 +148,7 @@ class TestOperationResource(RestResourceTest):
 
         dummy_file = FileStorage(BytesIO(b"test"), 'test.h5')
         # Mock flask.request.files to return a dictionary
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         request_mock.files = {RequestFileKey.LAUNCH_ANALYZERS_MODEL_FILE.value: dummy_file}
 
         with pytest.raises(ServiceException): self.launch_resource.post(project_gid=self.test_project.gid,
@@ -167,13 +164,13 @@ class TestOperationResource(RestResourceTest):
 
         fft_model = FFTAdapterModel()
         fft_model.time_series = UUID(input_ts_index.gid)
-        fft_model.window_function = list(SUPPORTED_WINDOWING_FUNCTIONS)[0]
+        fft_model.window_function = WindowingFunctionsEnum.HAMMING
 
-        input_folder = self.files_helper.get_project_folder(self.test_project)
+        input_folder = self.storage_interface.get_project_folder(self.test_project.name)
         view_model_h5_path = h5.store_view_model(fft_model, input_folder)
 
         # Mock flask.request.files to return a dictionary
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         fp = open(view_model_h5_path, 'rb')
         request_mock.files = {
             RequestFileKey.LAUNCH_ANALYZERS_MODEL_FILE.value: FileStorage(fp, os.path.basename(view_model_h5_path))}
@@ -189,6 +186,3 @@ class TestOperationResource(RestResourceTest):
 
         assert type(operation_gid) is str
         assert len(operation_gid) > 0
-
-    def transactional_teardown_method(self):
-        self.files_helper.remove_project_structure(self.test_project.name)
