@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 #
 #
-# TheVirtualBrain-Scientific Package. This package holds all simulators, and
-# analysers necessary to run brain-simulations. You can use it stand alone or
-# in conjunction with TheVirtualBrain-Framework Package. See content of the
+# TheVirtualBrain-Framework Package. This package holds all Data Management, and
+# Web-UI helpful to run brain-simulations. To use it, you also need to download
+# TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2023, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -19,21 +19,16 @@
 #
 #
 #   CITATION:
-# When using The Virtual Brain for scientific publications, please cite it as follows:
-#
-#   Paula Sanz Leon, Stuart A. Knock, M. Marmaduke Woodman, Lia Domide,
-#   Jochen Mersmann, Anthony R. McIntosh, Viktor Jirsa (2013)
-#       The Virtual Brain: a simulator of primate brain network dynamics.
-#   Frontiers in Neuroinformatics (7:10. doi: 10.3389/fninf.2013.00010)
+# When using The Virtual Brain for scientific publications, please cite it as explained here:
+# https://www.thevirtualbrain.org/tvb/zwei/neuroscience-publications
 #
 #
 
 import os
 from io import BytesIO
-
 import flask
 import pytest
-from tvb.core.entities.file.files_helper import FilesHelper
+
 from tvb.core.entities.file.simulator.view_model import SimulatorAdapterModel
 from tvb.core.entities.model.model_operation import Operation
 from tvb.core.neocom import h5
@@ -41,7 +36,7 @@ from tvb.core.services.simulator_service import SimulatorService
 from tvb.interfaces.rest.commons.exceptions import InvalidIdentifierException
 from tvb.interfaces.rest.commons.strings import RequestFileKey
 from tvb.interfaces.rest.server.resources.simulator.simulation_resource import FireSimulationResource
-from tvb.simulator.simulator import Simulator
+from tvb.storage.storage_interface import StorageInterface
 from tvb.tests.framework.core.factory import TestFactory
 from tvb.tests.framework.interfaces.rest.base_resource_test import RestResourceTest
 from werkzeug.datastructures import FileStorage
@@ -53,14 +48,14 @@ class TestSimulationResource(RestResourceTest):
         self.test_user = TestFactory.create_user('Rest_User')
         self.test_project = TestFactory.create_project(self.test_user, 'Rest_Project', users=[self.test_user.id])
         self.simulation_resource = FireSimulationResource()
-        self.files_helper = FilesHelper()
+        self.storage_interface = StorageInterface()
 
     def test_server_fire_simulation_inexistent_gid(self, mocker):
         self._mock_user(mocker)
         project_gid = "inexistent-gid"
         dummy_file = FileStorage(BytesIO(b"test"), 'test.zip')
         # Mock flask.request.files to return a dictionary
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         request_mock.files = {RequestFileKey.SIMULATION_FILE_KEY.value: dummy_file}
 
         with pytest.raises(InvalidIdentifierException): self.simulation_resource.post(project_gid=project_gid)
@@ -68,7 +63,7 @@ class TestSimulationResource(RestResourceTest):
     def test_server_fire_simulation_no_file(self, mocker):
         self._mock_user(mocker)
         # Mock flask.request.files to return a dictionary
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         request_mock.files = {}
 
         with pytest.raises(InvalidIdentifierException): self.simulation_resource.post(project_gid='')
@@ -77,14 +72,14 @@ class TestSimulationResource(RestResourceTest):
         self._mock_user(mocker)
         dummy_file = FileStorage(BytesIO(b"test"), 'test.txt')
         # Mock flask.request.files to return a dictionary
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         request_mock.files = {RequestFileKey.SIMULATION_FILE_KEY.value: dummy_file}
 
         with pytest.raises(InvalidIdentifierException): self.simulation_resource.post(project_gid='')
 
     def test_server_fire_simulation(self, mocker, connectivity_factory):
         self._mock_user(mocker)
-        input_folder = self.files_helper.get_project_folder(self.test_project)
+        input_folder = self.storage_interface.get_project_folder(self.test_project.name)
         sim_dir = os.path.join(input_folder, 'test_sim')
         if not os.path.isdir(sim_dir):
             os.makedirs(sim_dir)
@@ -94,10 +89,10 @@ class TestSimulationResource(RestResourceTest):
         h5.store_view_model(simulator, sim_dir)
 
         zip_filename = os.path.join(input_folder, RequestFileKey.SIMULATION_FILE_NAME.value)
-        FilesHelper().zip_folder(zip_filename, sim_dir)
+        self.storage_interface.write_zip_folder(zip_filename, sim_dir)
 
         # Mock flask.request.files to return a dictionary
-        request_mock = mocker.patch.object(flask, 'request')
+        request_mock = mocker.patch.object(flask, 'request', spec={})
         fp = open(zip_filename, 'rb')
         request_mock.files = {RequestFileKey.SIMULATION_FILE_KEY.value: FileStorage(fp, os.path.basename(zip_filename))}
 
@@ -112,6 +107,3 @@ class TestSimulationResource(RestResourceTest):
 
         assert type(operation_gid) is str
         assert status == 201
-
-    def transactional_teardown_method(self):
-        self.files_helper.remove_project_structure(self.test_project.name)
